@@ -42,6 +42,9 @@ use std::os::unix::fs::PermissionsExt;
 pub const BEGINNING_ROW: u16 = 3;
 pub const EMPTY_WARNING: &str = "Are you sure to empty the trash directory? (if yes: y)";
 
+const MAX_SIZE_TO_PREVIEW: u64 = 1_000_000_000;
+const MAX_SIZE_TO_PREVIEW_TEXT: u64 = 1_000_000;
+
 #[derive(Debug, Default)]
 pub struct State {
     pub list: Vec<ItemInfo>,
@@ -187,7 +190,8 @@ impl Registers {
     }
 }
 
-/// To avoid cost copying ItemInfo, use ItemBuffer when tinkering with register.
+/// To avoid cost copying ItemInfo, use ItemBuffer
+/// when tinkering with register or multiple renaming.
 #[derive(Debug, Clone)]
 pub struct ItemBuffer {
     pub file_type: FileType,
@@ -502,7 +506,7 @@ impl State {
         let duration = duration_to_string(start.elapsed());
         let delete_message: String = {
             if total == 1 {
-                format!("1 item deleted [{}]", duration)
+                format!("1 item deleted. [{}]", duration)
             } else {
                 let mut count = total.to_string();
                 let _ = write!(count, " items deleted [{}]", duration);
@@ -918,7 +922,9 @@ impl State {
     pub fn undo(&mut self, op: &OpKind) -> Result<(), FxError> {
         match op {
             OpKind::Rename(op) => {
-                std::fs::rename(&op.new_name, &op.original_name)?;
+                for (original, new) in op {
+                    std::fs::rename(new, original)?;
+                }
                 self.operations.pos += 1;
                 self.update_list()?;
                 self.clear_and_show_headline();
@@ -956,7 +962,9 @@ impl State {
     pub fn redo(&mut self, op: &OpKind) -> Result<(), FxError> {
         match op {
             OpKind::Rename(op) => {
-                std::fs::rename(&op.original_name, &op.new_name)?;
+                for (original, new) in op {
+                    std::fs::rename(original, new)?;
+                }
                 self.operations.pos -= 1;
                 self.update_list()?;
                 self.clear_and_show_headline();
@@ -1284,6 +1292,56 @@ impl State {
         self.list = result;
     }
 
+    /// Rename selected items at once.
+    pub fn rename_multiple_items(&mut self, items: &[ItemBuffer]) -> Result<usize, FxError> {
+        let names: Vec<&str> = items.iter().map(|item| item.file_name.as_str()).collect();
+        let mut file = tempfile::NamedTempFile::new()?;
+        writeln!(file, "{}", names.join("\n"))?;
+
+        let mut default = Command::new(&self.default);
+        let path = file.into_temp_path();
+        if let Err(e) = default
+            .arg(&path)
+            .status()
+            .map_err(|_| FxError::DefaultEditor)
+        {
+            Err(e)
+        } else {
+            let new_names = fs::read_to_string(&path)?;
+            // clean up temp file
+            path.close()?;
+            let new_names: Vec<&str> = new_names
+                .split('\n')
+                .filter(|name| !name.is_empty())
+                .collect();
+            if new_names.len() != items.len() {
+                Err(FxError::Io(
+                    format!(
+                        "Rename failed: Expected {} names, but received {} names",
+                        items.len(),
+                        new_names.len()
+                    )
+                    .to_string(),
+                ))
+            } else {
+                let mut result: Vec<(PathBuf, PathBuf)> = vec![];
+                for (i, new_name) in new_names.iter().enumerate() {
+                    let mut to = self.current_dir.clone();
+                    to.push(new_name);
+                    if &items[i].file_name != new_name {
+                        std::fs::rename(&items[i].file_path, &to)?;
+                        result.push((items[i].file_path.clone(), to))
+                    }
+                }
+                let len = result.len();
+                self.operations.branch();
+                self.operations.push(OpKind::Rename(result));
+
+                Ok(len)
+            }
+        }
+    }
+
     /// Reset all item's selected state and exit the select mode.
     pub fn reset_selection(&mut self) {
         for item in self.list.iter_mut() {
@@ -1880,29 +1938,6 @@ fn read_item(entry: fs::DirEntry) -> ItemInfo {
     }
 }
 
-/// Generate item information from trash directory, in order to use when redoing.
-// pub fn sellect_buffer(trash_dir: &PathBuf, vec: &[ItemBuffer]) -> Result<Vec<ItemBuffer>, FxError> {
-//     let total = vec.len();
-//     let mut count = 0;
-//     let mut result = Vec::new();
-//     for entry in fs::read_dir(trash_dir)? {
-//         let entry = entry?;
-//         if vec
-//             .iter()
-//             .map(|x| x.file_path.clone())
-//             .collect::<Vec<PathBuf>>()
-//             .contains(&entry.path())
-//         {
-//             result.push(ItemBuffer::new(&read_item(entry)));
-//             count += 1;
-//             if count == total {
-//                 break;
-//             }
-//         }
-//     }
-//     Ok(result)
-// }
-
 /// Check if zoxide is installed.
 fn check_zoxide() -> bool {
     std::process::Command::new("zoxide")
@@ -1914,11 +1949,15 @@ fn check_zoxide() -> bool {
 /// Set content type from ItemInfo.
 fn set_preview_content_type(item: &mut ItemInfo) {
     if item.file_size > MAX_SIZE_TO_PREVIEW {
-        item.preview_type = Some(PreviewType::TooBigSize);
+        item.preview_type = Some(PreviewType::TooLargeImage);
     } else if is_supported_image(item) {
         item.preview_type = Some(PreviewType::Image);
     } else if let Ok(content) = &std::fs::read(&item.file_path) {
         if content_inspector::inspect(content).is_text() {
+            if item.file_size > MAX_SIZE_TO_PREVIEW_TEXT {
+                item.preview_type = Some(PreviewType::TooLargeText);
+                return;
+            }
             if let Ok(content) = String::from_utf8(content.to_vec()) {
                 let content = content.replace('\t', "    ");
                 item.content = Some(content);
@@ -2050,21 +2089,22 @@ mod tests {
 
     #[test]
     fn test_has_write_permission() {
-        // chmod to 444 and check if it's read-only
         let p = std::path::PathBuf::from("./testfiles/permission_test");
-        let _status = std::process::Command::new("chmod")
-            .args(["444", "./testfiles/permission_test"])
-            .status()
-            .unwrap();
-        assert!(!has_write_permission(p.as_path()).unwrap());
-        let _status = std::process::Command::new("chmod")
-            .args(["755", "./testfiles/permission_test"])
-            .status()
-            .unwrap();
+        assert!(has_write_permission(&p).unwrap());
 
-        // Test the home directory, which should pass
+        // chmod to 444 and check if it's read-only
+        let mut perms = std::fs::metadata(&p).unwrap().permissions();
+        perms.set_readonly(true);
+        std::fs::set_permissions(&p, perms.clone()).unwrap();
+        assert!(!has_write_permission(&p).unwrap());
+
+        // HOME_DIR should pass as writable
         let home_dir = dirs::home_dir().unwrap();
         assert!(has_write_permission(&home_dir).unwrap());
+
+        // Set the file writable
+        perms.set_readonly(false);
+        std::fs::set_permissions(&p, perms).unwrap();
     }
 
     #[test]
